# iranintl
## about
[**Iran International**](https://www.iranintl.com/) is a Persian-language satellite television channel and multilingual digital news operation established in May 2017, headquartered originally in London and temporarily relocated to Washington

It is recognized as the most influential independent news source inside Iran, with a 2022 survey showing 33% of daily Iranian viewers trust it "a lot" or "to some extent," making it the most popular Persian-language foreign broadcaster in Iran

for more information about Iran International you can visit [perplexity.ai](https://www.perplexity.ai/search/tell-me-about-iran-internation-FiwZip5DTZG9igYKlRRFSw)
## install
```
pip install iranintl
```
## usage

refer to [example_usage.py](./example_usage.py)

for types: [types.py](./iranintl/types.py)
